@@ -77,7 +77,7 @@ PCAsimilarity.list <- function (cov.x, cov.y = NULL, ...,
 #' @export
 PCAsimilarity.mcmc_sample <- function (cov.x, cov.y, ..., parallel = FALSE)
 {
-  if (class (cov.y) == "mcmc_sample") {
+  if (is(cov.y, "mcmc_sample")) {
     n = dim(cov.x)[1]
     if(dim(cov.y)[1] != n) stop("samples must be of same size")
     cov.x <- alply(cov.x, 1)
